Learn R Programming

GxEprs (version 1.1)

Bphe_target: Phenotype data file of the target dataset when the outcome is binary. This contains phenotype information of the individuals in the target dataset.

Description

Phenotype data file of the target dataset when the outcome is binary. This contains phenotype information of the individuals in the target dataset.

Usage

Bphe_target

Arguments

Format

A dataframe with 200 rows and 3 columns

Column 1

Family ID

Column 2

Individual ID

Column 3

Phenotype (0=controls, 1=cases)