Qphe_discovery: Phenotype data file of the discovery dataset when the outcome is quantitative.
This contains phenotype information of the individuals in the discovery dataset.
Description
Phenotype data file of the discovery dataset when the outcome is quantitative.
This contains phenotype information of the individuals in the discovery dataset.