Qphe_target: Phenotype data file of the target dataset when the outcome is quantitative.
This contains phenotype information of the individuals in the target dataset.
Description
Phenotype data file of the target dataset when the outcome is quantitative.
This contains phenotype information of the individuals in the target dataset.